=====================
Selenium Configurator
=====================

.. image:: https://api.travis-ci.org/anybox/selenium-configurator.svg?branch=develop
   :target: https://travis-ci.org/anybox/selenium-configurator
   :alt: Travis state

.. image:: https://readthedocs.org/projects/selenium-configurator/badge/?style=flat
    :target: https://readthedocs.org/projects/selenium-configurator
    :alt: Documentation Status

This library provide an helper api for selenium launchers. it prepares multiple
selenium web drivers from a configuration file. This aims to help launchers to
run 1 task over multiple browsers through various selenium web drivers (local,
grid, cloud provider...).

Resources
=========

- `Documentation <https://selenium-configurator.readthedocs.org>`_
- `Issue Tracker <https://github.com/anybox/selenium-configurator/issues>`_
- `Code <https://github.com/anybox/selenium-configurator/>`_


Licence
=======

.. image:: http://www.gnu.org/graphics/lgplv3-88x31.png
   :target: http://www.gnu.org/licenses/lgpl-3.0.txt
   :alt: GNU Lesser General Public License v3 (LGPL-3.0)
